@@ -60,7 +60,7 @@ ExtWizard_Page::AdjustPage(wxBoxSizer *sizer, const wxString& helpfile) {
 	tqslTrace("ExtWizard_Page::AdjustPage", NULL);
 	_helpfile = helpfile;
 
-	if (_helpfile != wxT("") && _parent->HaveHelp()) {
+	if (!_helpfile.IsEmpty() && _parent->HaveHelp()) {
 		// Space filler
 		sizer->Add(new wxStaticText(this, -1, wxT("")), 1, 0, 10);
 		sizer->Add(new wxButton(this, EW_HELP_BUT, _("Help")), 0, wxALL, 10);
