@@ -131,9 +131,8 @@ tqsl_curl_init(const char *logTitle, const char *url, bool newFile) {
 	curl_easy_setopt(curlReq, CURLOPT_URL, url);
     curl_easy_setopt(curlReq, CURLOPT_SSL_VERIFYPEER, false);
 
-	wxStandardPaths sp;
 	wxString exePath;
-	wxFileName::SplitPath(sp.GetExecutablePath(), &exePath, 0, 0);
+	wxFileName::SplitPath(wxStandardPaths::Get().GetExecutablePath(), &exePath, 0, 0);
 	docpaths.Add(exePath);
 	wxString caBundlePath = docpaths.FindAbsoluteValidPath(wxT("ca-bundle.crt"));
 	if (!caBundlePath.IsEmpty()) {
