@@ -49,7 +49,7 @@ DLLEXPORTDATA int tQSL_Errno = 0;
 DLLEXPORTDATA TQSL_ADIF_GET_FIELD_ERROR tQSL_ADIF_Error;
 DLLEXPORTDATA const char *tQSL_BaseDir = 0;
 DLLEXPORTDATA const char *tQSL_RsrcDir = 0;
-DLLEXPORTDATA char tQSL_ErrorFile[256];
+DLLEXPORTDATA char tQSL_ErrorFile[TQSL_MAX_PATH_LEN];
 DLLEXPORTDATA char tQSL_CustomError[256];
 DLLEXPORTDATA char tQSL_ImportCall[256];
 DLLEXPORTDATA long tQSL_ImportSerial = 0;
